@@ -43,8 +43,7 @@ if not hasattr(ASTTransformer, 'visit_NameConstant'):
     ASTTransformer.visit_NameConstant = ASTTransformer.visit_Name
 
 
-class Journal:
-    __metaclass__ = PoolMeta
+class Journal(metaclass=PoolMeta):
     __name__ = 'account.payment.journal'
     company_party = fields.Function(fields.Many2One('party.party',
             'Company Party'), 'on_change_with_company_party')
@@ -132,8 +131,7 @@ loader = genshi.template.TemplateLoader(
     auto_reload=True)
 
 
-class Group:
-    __metaclass__ = PoolMeta
+class Group(metaclass=PoolMeta):
     __name__ = 'account.payment.group'
     sepa_messages = fields.One2Many('account.payment.sepa.message', 'origin',
         'SEPA Messages', readonly=True,
@@ -220,14 +218,16 @@ class Group:
 
     @property
     def sepa_payments(self):
+        pool = Pool()
+        Payment = pool.get('account.payment')
         keyfunc = self.sepa_group_payment_key
-        payments = sorted(self.payments, key=keyfunc)
+        # re-browse to align cache
+        payments = Payment.browse(sorted(self.payments, key=keyfunc))
         for key, grouped_payments in groupby(payments, key=keyfunc):
             yield dict(key), list(grouped_payments)
 
 
-class Payment:
-    __metaclass__ = PoolMeta
+class Payment(metaclass=PoolMeta):
     __name__ = 'account.payment'
 
     sepa_mandate = fields.Many2One('account.payment.sepa.mandate', 'Mandate',
@@ -261,6 +261,8 @@ class Payment:
     def copy(cls, payments, default=None):
         if default is None:
             default = {}
+        else:
+            default = default.copy()
         default.setdefault('sepa_mandate_sequence_type', None)
         return super(Payment, cls).copy(payments, default=default)
 
@@ -419,15 +421,19 @@ class Mandate(Workflow, ModelSQL, ModelView):
                 'cancel': {
                     'invisible': ~Eval('state').in_(
                         ['requested', 'validated']),
+                    'depends': ['state'],
                     },
                 'draft': {
                     'invisible': Eval('state') != 'requested',
+                    'depends': ['state'],
                     },
                 'request': {
                     'invisible': Eval('state') != 'draft',
+                    'depends': ['state'],
                     },
                 'validate_mandate': {
                     'invisible': Eval('state') != 'requested',
+                    'depends': ['state'],
                     },
                 })
         t = cls.__table__()
@@ -471,6 +477,15 @@ class Mandate(Workflow, ModelSQL, ModelView):
     def get_identification_readonly(self, name):
         return bool(self.identification)
 
+    def get_rec_name(self, name):
+        if self.identification:
+            return self.identification
+        return '(%s)' % self.id
+
+    @classmethod
+    def search_rec_name(cls, name, clause):
+        return [tuple(('identification',)) + tuple(clause[1:])]
+
     @classmethod
     def create(cls, vlist):
         pool = Pool()
@@ -505,8 +520,8 @@ class Mandate(Workflow, ModelSQL, ModelView):
     def copy(cls, mandates, default=None):
         if default is None:
             default = {}
-        default = default.copy()
-        default.setdefault('state', 'draft')
+        else:
+            default = default.copy()
         default.setdefault('payments', [])
         default.setdefault('signature_date', None)
         default.setdefault('identification', None)
@@ -535,7 +550,7 @@ class Mandate(Workflow, ModelSQL, ModelView):
             return 'RCUR'
 
     @classmethod
-    def has_payments(self, mandates, name):
+    def has_payments(cls, mandates, name):
         pool = Pool()
         Payment = pool.get('account.payment')
         payment = Payment.__table__
@@ -633,15 +648,19 @@ class Message(Workflow, ModelSQL, ModelView):
         cls._buttons.update({
                 'cancel': {
                     'invisible': ~Eval('state').in_(['draft', 'waiting']),
+                    'depends': ['state'],
                     },
                 'draft': {
                     'invisible': Eval('state') != 'waiting',
+                    'depends': ['state'],
                     },
                 'wait': {
                     'invisible': Eval('state') != 'draft',
+                    'depends': ['state'],
                     },
                 'do': {
                     'invisible': Eval('state') != 'waiting',
+                    'depends': ['state'],
                     },
                 })
 
@@ -656,7 +675,7 @@ class Message(Workflow, ModelSQL, ModelView):
 
         # Migration from 3.2
         if TableHandler.table_exist(Group._table):
-            group_table = TableHandler(Group, module_name)
+            group_table = Group.__table_handler__(module_name)
             if group_table.column_exist('sepa_message'):
                 group = Group.__table__()
                 table = cls.__table__()
